==> certmanager-model-v1beta1-6.0.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1beta1/ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl<A extends ACMEChallengeSolverHTTP01IngressPodTemplateFluent<A>> extends BaseFluent<A> implements ACMEChallengeSolverHTTP01IngressPodTemplateFluent<A>{
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl() {
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl(ACMEChallengeSolverHTTP01IngressPodTemplate instance) {
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
  }
  private ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder metadata;
  private ACMEChallengeSolverHTTP01IngressPodSpecBuilder spec;
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ACMEChallengeSolverHTTP01IngressPodObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ACMEChallengeSolverHTTP01IngressPodObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ACMEChallengeSolverHTTP01IngressPodObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluent.MetadataNested<A> withNewMetadata() {
    return new ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.MetadataNestedImpl();
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluent.MetadataNested<A> withNewMetadataLike(ACMEChallengeSolverHTTP01IngressPodObjectMeta item) {
    return new ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.MetadataNestedImpl(item);
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder().build());
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluent.MetadataNested<A> editOrNewMetadataLike(ACMEChallengeSolverHTTP01IngressPodObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ACMEChallengeSolverHTTP01IngressPodSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public ACMEChallengeSolverHTTP01IngressPodSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(ACMEChallengeSolverHTTP01IngressPodSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new ACMEChallengeSolverHTTP01IngressPodSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluent.SpecNested<A> withNewSpec() {
    return new ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.SpecNestedImpl();
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluent.SpecNested<A> withNewSpecLike(ACMEChallengeSolverHTTP01IngressPodSpec item) {
    return new ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.SpecNestedImpl(item);
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new ACMEChallengeSolverHTTP01IngressPodSpecBuilder().build());
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluent.SpecNested<A> editOrNewSpecLike(ACMEChallengeSolverHTTP01IngressPodSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl that = (ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl) o;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(metadata,  spec,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ACMEChallengeSolverHTTP01IngressPodObjectMetaFluentImpl<ACMEChallengeSolverHTTP01IngressPodTemplateFluent.MetadataNested<N>> implements ACMEChallengeSolverHTTP01IngressPodTemplateFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ACMEChallengeSolverHTTP01IngressPodObjectMeta item) {
      this.builder = new ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder(this);
    }
    ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder builder;
    public N and() {
      return (N) ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends ACMEChallengeSolverHTTP01IngressPodSpecFluentImpl<ACMEChallengeSolverHTTP01IngressPodTemplateFluent.SpecNested<N>> implements ACMEChallengeSolverHTTP01IngressPodTemplateFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(ACMEChallengeSolverHTTP01IngressPodSpec item) {
      this.builder = new ACMEChallengeSolverHTTP01IngressPodSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new ACMEChallengeSolverHTTP01IngressPodSpecBuilder(this);
    }
    ACMEChallengeSolverHTTP01IngressPodSpecBuilder builder;
    public N and() {
      return (N) ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  
}

==> certmanager-model-v1beta1-6.7.2-sources.jar: io/fabric8/certmanager/api/model/acme/v1beta1/ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.java <==
package io.fabric8.certmanager.api.model.acme.v1beta1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl<A extends ACMEChallengeSolverHTTP01IngressPodTemplateFluent<A>> extends BaseFluent<A> implements ACMEChallengeSolverHTTP01IngressPodTemplateFluent<A>{
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl() {
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl(ACMEChallengeSolverHTTP01IngressPodTemplate instance) {
    if (instance != null) {
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
    }
  }
  private ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder metadata;
  private ACMEChallengeSolverHTTP01IngressPodSpecBuilder spec;
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ACMEChallengeSolverHTTP01IngressPodObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ACMEChallengeSolverHTTP01IngressPodObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ACMEChallengeSolverHTTP01IngressPodObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.MetadataNested<A> withNewMetadata() {
    return new ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.MetadataNestedImpl();
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.MetadataNested<A> withNewMetadataLike(ACMEChallengeSolverHTTP01IngressPodObjectMeta item) {
    return new ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.MetadataNestedImpl(item);
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder().build());
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.MetadataNested<A> editOrNewMetadataLike(ACMEChallengeSolverHTTP01IngressPodObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ACMEChallengeSolverHTTP01IngressPodSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public ACMEChallengeSolverHTTP01IngressPodSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(ACMEChallengeSolverHTTP01IngressPodSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new ACMEChallengeSolverHTTP01IngressPodSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.SpecNested<A> withNewSpec() {
    return new ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.SpecNestedImpl();
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.SpecNested<A> withNewSpecLike(ACMEChallengeSolverHTTP01IngressPodSpec item) {
    return new ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.SpecNestedImpl(item);
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new ACMEChallengeSolverHTTP01IngressPodSpecBuilder().build());
  }
  public ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.SpecNested<A> editOrNewSpecLike(ACMEChallengeSolverHTTP01IngressPodSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl that = (ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl) o;
    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(metadata,  spec,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ACMEChallengeSolverHTTP01IngressPodObjectMetaFluentImpl<ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.MetadataNested<N>> implements ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ACMEChallengeSolverHTTP01IngressPodObjectMeta item) {
      this.builder = new ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder(this);
    }
    ACMEChallengeSolverHTTP01IngressPodObjectMetaBuilder builder;
    public N and() {
      return (N) ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends ACMEChallengeSolverHTTP01IngressPodSpecFluentImpl<ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.SpecNested<N>> implements ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(ACMEChallengeSolverHTTP01IngressPodSpec item) {
      this.builder = new ACMEChallengeSolverHTTP01IngressPodSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new ACMEChallengeSolverHTTP01IngressPodSpecBuilder(this);
    }
    ACMEChallengeSolverHTTP01IngressPodSpecBuilder builder;
    public N and() {
      return (N) ACMEChallengeSolverHTTP01IngressPodTemplateFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  
}
